@@ -2,7 +2,7 @@
 
 ;;; File: "_gambit#.scm"
 
-;;; Copyright (c) 1994-2012 by Marc Feeley, All Rights Reserved.
+;;; Copyright (c) 1994-2014 by Marc Feeley, All Rights Reserved.
 
 ;;;============================================================================
 
@@ -62,8 +62,8 @@
 (##define-macro (macro-subtype-flonum)       30)
 (##define-macro (macro-subtype-bignum)       31)
 
-(##define-macro (macro-subtype-ovector? x) `(##fixnum.< ,x 8))
-(##define-macro (macro-subtype-bvector? x) `(##fixnum.< 16 ,x))
+(##define-macro (macro-subtype-ovector? x) `(##fx< ,x 8))
+(##define-macro (macro-subtype-bvector? x) `(##fx< 16 ,x))
 
 ;;- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
@@ -132,10 +132,11 @@
 ##flonum.<-fixnum-exact?
 ;;; ##flonum.= ##flonum.< ##flonum.> ##flonum.<= ##flonum.>=
 
-##fx->char ##fx<-char
-##fl->fx ##fl<-fx
-##fl<-fx-exact?
+##fx->char ##fx<-char;;deprecated
+##fl->fx ##fl<-fx;;deprecated
+##fl<-fx-exact?;;deprecated
 
+##integer->char ##char->integer
 
 ;;; ##fxmax ##fxmin
 ;;; ##fxwrap+ ##fx+
@@ -157,21 +158,22 @@
 ##fxwraplogical-shift-right
 ##fxwraplogical-shift-right?
 ##fxwrapabs ##fxabs ##fxabs?
+##fxwrapsquare ##fxsquare ##fxsquare?
 ##fxzero? ##fxpositive? ##fxnegative?
 ##fxodd? ##fxeven?
 ;;; ##fx= ##fx< ##fx> ##fx<= ##fx>=
-##fixnum->char ##char->fixnum
+##fixnum->char ##char->fixnum;;deprecated
 
 ##flonum->fixnum ##fixnum->flonum ##fixnum->flonum-exact?
 ;;; ##flmax ##flmin
 ;;; ##fl+ ##fl- ##fl*  ##fl/
 ##flabs
 ##flfloor ##flceiling ##fltruncate ##flround
-##flexp ##fllog
-##flsin ##flcos ##fltan
-##flasin ##flacos
-;;; ##flatan
-##flexpt ##flsqrt
+##flscalbn ##flilogb
+##flexp ##flexpm1 ##fllog ##fllog1p
+##flsin ##flcos ##fltan ##flasin ##flacos ;;; ##flatan
+##flsinh ##flcosh ##fltanh ##flasinh ##flacosh ##flatanh
+##flexpt ##flsqrt ##flsquare
 ##flcopysign
 ##flinteger? ##flzero? ##flpositive? ##flnegative?
 ##flodd? ##fleven?
@@ -249,8 +251,8 @@
 ##bignum.adigit-negative?
 ##bignum.adigit-=
 ##bignum.adigit-<
-##bignum.->fixnum
-##bignum.<-fixnum
+##bignum->fixnum
+##fixnum->bignum
 ##bignum.adigit-shrink!
 ##bignum.adigit-copy!
 ##bignum.adigit-cat!
@@ -384,8 +386,8 @@
 ;; slot 5 = value of entry #0
 
 (##define-macro (macro-gc-hash-table-nb-entries ht)
-  `(##fixnum.arithmetic-shift-right
-    (##fixnum.- (##vector-length ,ht) (macro-gc-hash-table-key0))
+  `(##fxarithmetic-shift-right
+    (##fx- (##vector-length ,ht) (macro-gc-hash-table-key0))
     1))
 
 (##define-macro (macro-gc-hash-table-minimal-nb-entries) 5)
@@ -409,8 +411,8 @@
 (##define-macro (macro-make-gc-hash-table flags count min-count free length)
   `(let ((ht
           (##make-vector
-           (##fixnum.+ (##fixnum.arithmetic-shift-left ,length 1)
-                       (macro-gc-hash-table-key0))
+           (##fx+ (##fxarithmetic-shift-left ,length 1)
+                  (macro-gc-hash-table-key0))
            (macro-unused-obj))))
      (macro-gc-hash-table-flags-set! ht ,flags)
      (macro-gc-hash-table-count-set! ht ,count)
@@ -439,14 +441,14 @@
 (##define-macro (macro-gc-hash-table-flag-need-rehash)    32)
 
 (##define-macro (macro-gc-hash-table-key-ref ht i*2)
-  `(##vector-ref ,ht (##fixnum.+ ,i*2 (macro-gc-hash-table-key0))))
+  `(##vector-ref ,ht (##fx+ ,i*2 (macro-gc-hash-table-key0))))
 (##define-macro (macro-gc-hash-table-key-set! ht i*2 x)
-  `(##vector-set! ,ht (##fixnum.+ ,i*2 (macro-gc-hash-table-key0)) ,x))
+  `(##vector-set! ,ht (##fx+ ,i*2 (macro-gc-hash-table-key0)) ,x))
 
 (##define-macro (macro-gc-hash-table-val-ref ht i*2)
-  `(##vector-ref ,ht (##fixnum.+ ,i*2 (macro-gc-hash-table-val0))))
+  `(##vector-ref ,ht (##fx+ ,i*2 (macro-gc-hash-table-val0))))
 (##define-macro (macro-gc-hash-table-val-set! ht i*2 x)
-  `(##vector-set! ,ht (##fixnum.+ ,i*2 (macro-gc-hash-table-val0)) ,x))
+  `(##vector-set! ,ht (##fx+ ,i*2 (macro-gc-hash-table-val0)) ,x))
 
 ;;- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
@@ -456,6 +458,11 @@
 ;; slot 0 = frame object
 ;; slot 1 = dynamic-environment
 
+(##define-macro (macro-make-continuation frame denv)
+  `(##subtype-set!
+    (##vector ,frame ,denv)
+    (macro-subtype-continuation)))
+
 (##define-macro (macro-continuation-frame c)        `(macro-slot 0 ,c))
 (##define-macro (macro-continuation-frame-set! c x) `(macro-slot 0 ,c ,x))
 (##define-macro (macro-continuation-denv c)         `(macro-slot 1 ,c))
@@ -477,6 +484,18 @@
 (##define-macro (macro-promise-result p)        `(macro-slot 1 ,p))
 (##define-macro (macro-promise-result-set! p x) `(macro-slot 1 ,p ,x))
 
+;;- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+
+;; Foreign objects
+
+;; A foreign object is represented by an object vector of length 3
+;; slot 0 = tags
+;; slot 1 = C pointer to release function
+;; slot 2 = C pointer to foreign data
+
+(##define-macro (macro-foreign-tags f)         `(macro-slot 0 ,f))
+(##define-macro (macro-foreign-tags-set! f x)  `(macro-slot 0 ,f ,x))
+
 ;;;----------------------------------------------------------------------------
 
 (##define-macro (macro-if-forces forces noforces)
@@ -576,7 +595,7 @@
                           (if (eq? (car check) '##pair?)
                             (let ((x (list '##car name-result)))
                               (list (if arg-num
-                                        (list '##fixnum.+ arg-num x)
+                                        (list '##fx+ arg-num x)
                                         x)))
                             '())
                           (list ''()
@@ -656,7 +675,7 @@
                             '(next)
                             (add-pre-check
                              'next
-                             '(##fixnum.+ arg-num 3)
+                             '(##fx+ arg-num 3)
                              (if bool?
                                (list 'loop
                                      (list 'and
@@ -665,12 +684,12 @@
                                      name-param2
                                      'next
                                      '(##cdr lst)
-                                     '(##fixnum.+ arg-num 1))
+                                     '(##fx+ arg-num 1))
                                (list 'loop
                                      result
                                      'next
                                      '(##cdr lst)
-                                     '(##fixnum.+ arg-num 1)))))))))))
+                                     '(##fx+ arg-num 1)))))))))))
 
     (define (body)
       (cons 'cond
@@ -966,7 +985,7 @@
            ,@(if id
                `(id: ,id)
                `())
-           ,@(if (##fixnum.= (##fixnum.bitwise-and flags 1) 0)
+           ,@(if (##fx= (##fxand flags 1) 0)
                `()
                `(opaque:))
            ,@(if extender
@@ -998,13 +1017,13 @@
                           ,@(if (##symbol? setter)
                               `(,setter)
                               `())
-                          ,@(if (##fixnum.= (##fixnum.bitwise-and options 1) 0)
+                          ,@(if (##fx= (##fxand options 1) 0)
                               `()
                               `(unprintable:))
-                          ,@(if (##fixnum.= (##fixnum.bitwise-and options 2) 0)
+                          ,@(if (##fx= (##fxand options 2) 0)
                               `()
                               `(read-only:))
-                          ,@(if (##fixnum.= (##fixnum.bitwise-and options 4) 0)
+                          ,@(if (##fx= (##fxand options 4) 0)
                               `()
                               `(equality-skip:))
                           ,@(let loop ((lst1 attributes)
